type SerializeFunction<T> = (key: keyof T, value: unknown) => string;
type DeserializeFunction<T> = (key: keyof T, value: string) => unknown;
/**
 * A function that synchronizes an object (`data`) with URL query parameters.
 *
 * @param {Record<string, any>} data - An object containing key-value pairs that you want to sync with the URL.
 * @param {object} [options] - Optional configuration for serialization, deserialization, and URL update behavior.
 * @param {SerializeFunction<T>} [options.serialize] - A custom serialization function to convert an object into a query string.
 * @param {DeserializeFunction<T>} [options.deserialize] - A custom deserialization function to convert a query string back into an object.
 * @param {boolean} [options.updateUrl=true] - A flag to determine whether the URL should be automatically updated when the data changes.
 *
 * @returns {object} - An object containing `initializeDataFromQuery` to initialize data from the query string,
 * and `updateQueryParams` to manually trigger the query string update.
 */
export declare function useQueryParams<T extends Record<string, any>>(data: T, options?: {
    serialize?: SerializeFunction<T>;
    deserialize?: DeserializeFunction<T>;
    updateUrl?: boolean;
}): {
    initializeDataFromQuery: () => void;
    updateQueryParams: () => void;
};
export {};
//# sourceMappingURL=useQueryParams.d.ts.map